<?php
   class clsHabit extends BDConexion
   {
     function clsHabit()
     {
       $this->conectar();
     }
	 function getComprobanteV()
     {
       $ssql="select * ";
       $ssql.=" From comprobantes where tipo='V'";       
       return $this->BDConsulta($ssql);
     }
	 function getComprobanteT($tipo)
     {
       $ssql="select * ";
       $ssql.=" From comprobantes where tipo='$tipo'";       
       return $this->BDConsulta($ssql);
     }
	 function getDetSerV($iddetserv)
     {
       $ssql="select * ";
       $ssql.=" From detalleservicio where iddetserv=$iddetserv";       
       return $this->BDConsulta($ssql);
     }
	 function devolverNombreHuesped($idhabit)
     {
       $ssql="select h.*,a.* ";
       $ssql.=" From huesped as h,alojamiento as a where h.idhuesped=a.idhuesped and a.idhabit=$idhabit and a.estadoaloja='O'";       
       return $this->BDConsulta($ssql);
     }
	 function devolverHuespedC($idhuesped)
     {
       $ssql="select h.*,c.*,p.* ";
       $ssql.=" From huesped as h,ciudad as c,pais as p where h.huesped like '$like%' and p.idpais=c.idpais and c.idciudad=h.idciudad";       
       return $this->BDConsulta($ssql);
     }
	 function devolverNombreHuespedR($idhabit)
     {
       $ssql="select h.*,a.* ";
       $ssql.=" From huesped as h,alojamiento as a where h.idhuesped=a.idhuesped and a.idhabit=$idhabit and a.estadoaloja='R'";       
       return $this->BDConsulta($ssql);
     }
	 function devolverNombreHuespedRR($idhabit)
     {
       $ssql="select h.*,a.* ";
       $ssql.=" From huesped as h,alojamiento as a where h.idhuesped=a.idhuesped and a.idhabit=$idhabit and a.estadoaloja='R'";       
       return $this->BDConsulta($ssql);
     }
     function getHabit()
     {
       $ssql="select * ";
       $ssql.=" From habitacion ";       
       return $this->BDConsulta($ssql);
     }
	 function getNdias($fechareserva,$idalojamiento)
     {
       $ssql="SELECT (TO_DAYS(NOW())-TO_DAYS('$fechareserva'))+1 as fecha ";
       $ssql.=" FROM alojamiento as a where a.idalojamiento=$idalojamiento and a.estadoaloja='R' ";       
       return $this->BDConsulta($ssql);
     }
	 function getNdiasHabit($fechaingre,$idalojamiento)
     {
       $ssql="SELECT (TO_DAYS(NOW())-TO_DAYS('$fechaingre'))+1 as fecha ";
       $ssql.=" FROM alojamiento as a where a.idalojamiento=$idalojamiento and a.estadoaloja='O' ";       
       return $this->BDConsulta($ssql);
     }
	 function devolverServicios($like)
     {
       $ssql="select * ";
       $ssql.=" From servicio where nomservicio like '$like%' and idservicio<>1 ";       
       return $this->BDConsulta($ssql);
     }
	 function devolverDetServicios($idalojamiento)
     {
       $ssql="select s.nomservicio,d.idservicio,d.idalojamiento,sum(d.cantidad) as cantidad,d.precio,d.subtotal,d.fecha,d.hora,d.precios,sum(d.subtotals) as subtotals,d.um  ";
       $ssql.=" From alojamiento as a,servicio as s,detalleservicio as d where a.idalojamiento=d.idalojamiento and d.idservicio=s.idservicio and s.idservicio<>1 group by d.idservicio";       
       return $this->BDConsulta($ssql);
     }
	 function devolverDetServicioHabit($idalojamiento)
     {
       $ssql="select a.*,s.*,d.*";
       $ssql.=" From alojamiento as a,servicio as s,detalleservicio as d where a.idalojamiento=d.idalojamiento and d.idservicio=s.idservicio and s.idservicio=1 ";       
       return $this->BDConsulta($ssql);
     }
	 function devolverServiciosId($idservicio)
     {
       $ssql="select * ";
       $ssql.=" From servicio where idservicio=$idservicio and idservicio<>1 ";       
       return $this->BDConsulta($ssql);
     }
	 function getHabitPag($regini,$regxpag)
     {
       $ssql="select * ";
       $ssql.=" From habitacion limit $regini,$regxpag";       
       return $this->BDConsulta($ssql);
     }
	 function getHabitDispoPag($regini,$regxpag)
     {
       $ssql="select * ";
       $ssql.=" From habitacion where estadohabit='D' limit $regini,$regxpag";       
       return $this->BDConsulta($ssql);
     }
	 function devolverHuespedAlojaPag($regini,$regxpag)
     {
       $ssql="select h.*,a.*,ha.* ";
       $ssql.=" From huesped as h,alojamiento as a,habitacion as ha where h.idhuesped=a.idhuesped and a.idhabit=ha.idhabit and a.estadoaloja='O' limit $regini,$regxpag";       
       return $this->BDConsulta($ssql);
     }
	 function devolverHuespedIdaloja($idalojamiento)
     {
       $ssql="select h.*,a.*,ha.* ";
       $ssql.=" From huesped as h,alojamiento as a,habitacion as ha where h.idhuesped=a.idhuesped and a.idhabit=ha.idhabit and a.estadoaloja='O' and a.idalojamiento=$idalojamiento";       
       return $this->BDConsulta($ssql);
     }
	 function getHuespedPag($like,$regini,$regxpag)
     {
       $ssql="select h.*,p.*,c.* ";
       $ssql.=" From huesped as h,ciudad as c,pais as p where h.huesped like '$like%' and p.idpais=c.idpais and c.idciudad=h.idciudad limit $regini,$regxpag";       
       return $this->BDConsulta($ssql);
     }
	 function getHuespedT($like)
     {
       $ssql="select h.*,p.*,c.* ";
       $ssql.=" From huesped as h,ciudad as c,pais as p where h.huesped like '$like%' and p.idpais=c.idpais and c.idciudad=h.idciudad";       
       return $this->BDConsulta($ssql);
     }
	 
	 function getPaisT($like)
     {
       $ssql="select p.*,c.* ";
       $ssql.=" From pais as p,ciudad as c where p.idpais=c.idpais and nombrepais like '$like%' and p.idpais<>1";       
       return $this->BDConsulta($ssql);
     }
	 function getPaisesT($idpais)
     {
       $ssql="select p.*,c.* ";
       $ssql.=" From pais as p,ciudad as c where p.idpais=c.idpais and p.idpais=$idpais";       
       return $this->BDConsulta($ssql);
     }
	 function getPaisM()
     {
       $ssql="select p.* ";
       $ssql.=" From pais as p where p.idpais<>1";       
       return $this->BDConsulta($ssql);
     }
	 function getPaisP()
     {
       $ssql="select p.* ";
       $ssql.=" From pais as p where p.idpais=1";       
       return $this->BDConsulta($ssql);
     }
	 function getPaisPeruPag($like,$regini,$regxpag)
     {
       $ssql="select p.*,c.* ";
       $ssql.=" From pais as p,ciudad as c where p.idpais=c.idpais and nombrepais like '$like%' and p.idpais=1 limit $regini,$regxpag";       
       return $this->BDConsulta($ssql);
     }
	 function getPaisPag($like,$regini,$regxpag)
     {
       $ssql="select p.*,c.* ";
       $ssql.=" From pais as p,ciudad as c where p.idpais=c.idpais and nombrepais like '$like%' and p.idpais<>1 limit $regini,$regxpag";       
       return $this->BDConsulta($ssql);
     }
	 function getPaisesPag($idciudad)
     {
       $ssql="select p.*,c.* ";
       $ssql.=" From pais as p,ciudad as c where p.idpais=c.idpais and c.idciudad=$idciudad";       
       return $this->BDConsulta($ssql);
     }
	 function getPaisPeruT($like)
     {
       $ssql="select p.*,c.* ";
       $ssql.=" From pais as p,ciudad as c where p.idpais=c.idpais and nombrepais like '$like%' and p.idpais=1";       
       return $this->BDConsulta($ssql);
     }
     function getCboPaisM($idpais)
     {
       $lista="";
       $resultado=$this->getPaisM();
       while($filas=$this->NextRow($resultado))
       {
         if($idpais==$filas[0])
           $lista.="<option value='".$filas[0]."' selected>".$filas[1]."</option>".chr(13).chr(10);
         else
           $lista.="<option value='".$filas[0]."'>".$filas[1]."</option>".chr(13).chr(10);
       }
       $this->Liberar($resultado);
      return $lista;
     }
	 function getCboPaisP($idpais)
     {
       $lista="";
       $resultado=$this->getPaisP();
       while($filas=$this->NextRow($resultado))
       {
         if($idpais==$filas[0])
           $lista.="<option value='".$filas[0]."' selected>".$filas[1]."</option>".chr(13).chr(10);
         else
           $lista.="<option value='".$filas[0]."'>".$filas[1]."</option>".chr(13).chr(10);
       }
       $this->Liberar($resultado);
      return $lista;
     }	 
     function getUsuarioId($login,$clave)
     {
       $ssql="select idusuario from Usuario where login='".$login."' and clave='".$clave."' ";
       $resultado=$this->BDConsulta($ssql);
       if($filas=$this->NextRow($resultado))
           $idusuario=$filas[0];
       else
           $idusuario=0;
       $this->Liberar($resultado);
       return $idusuario;
     }
     function getUsuarioLogueo($idusuario)
     {
       $ssql="select nombres,apellidos,idarea ";
       $ssql.=" From Usuario Where idusuario=".$idusuario;
       return $this->BDConsulta($ssql);
     }
	 
	 function getMenuGrupo($idusuario)
     {
       $ssql="select menugrupo.nommenugrupo, menugrupo.idmenugrupo, menugrupo.archivo ";
       $ssql.=" From menu, permiso, menugrupo Where menu.idmenugrupo= menugrupo.idmenugrupo AND permiso.idmenu = menu.idmenu AND permiso.idusuario=".$idusuario." GROUP BY menugrupo.nommenugrupo, menugrupo.idmenugrupo";
       return $this->BDConsulta($ssql);
     }
	 
	 function getMenuItems($idmenugrupo,$idusuario)
     {
       $ssql="select menu.nommenu, menu.archivo, permiso.idmenu, menu.imgmenu ";
       $ssql.=" From menu, permiso Where menu.idmenugrupo=".$idmenugrupo." AND permiso.idmenu = menu.idmenu AND permiso.idusuario =".$idusuario." ORDER BY orden";
       return $this->BDConsulta($ssql);
     }
	 function registrarHuesped($huesped,$agencia,$direccion,$telefono,$profesion,$estadocivil,$idciudad,$docidentidad,$fecnac,$edad)
     {
      $ssql="Insert Into huesped(huesped,agencia,direccion,telefono,profesion,estadocivil,idciudad,docidentidad,fecnac,edad) values('$huesped','$agencia','$direccion','$telefono','$profesion','$estadocivil',$idciudad,'$docidentidad','$fecnac',$edad)";
      $this->BDConsulta($ssql); 	   
	  $id=$this->UltimoId();
	  return $id;        
     }
	 function UpdateHuesped($idhuesped,$huesped,$agencia,$direccion,$telefono,$profesion,$estadocivil,$idciudad,$docidentidad,$fecnac,$edad)
     {
      $ssql="update huesped set huesped='$huesped',agencia='$agencia',direccion='$direccion',telefono='$telefono',profesion='$profesion',estadocivil='$estadocivil',idciudad=$idciudad,docidentidad='$docidentidad',fecnac='$fecnac',edad=$edad where idhuesped=$idhuesped";
      $this->BDConsulta($ssql); 	        
     }	                           
	 function registrarAlojamiento($fechaingre,$fechasal,$horaingre,$procedencia,$destino,$idusuario,$idhabit,$idhuesped,$observacion,$estadoaloja)
     {
       $ssql="Insert Into alojamiento(fechaingre,fechasal,horaingre,procedencia,destino,idusuario,idhabit,idhuesped,observacion,estadoaloja) values('$fechaingre','$fechasal','$horaingre','$procedencia','$destino',$idusuario,$idhabit,$idhuesped,'$observacion','$estadoaloja')";
       $this->BDConsulta($ssql); 	   
	   $id=$this->UltimoId();
	   return $id; 
     }
	 function UpdateAlojamientoR($idalojamiento,$fechaingre,$fechasal,$horaingre,$procedencia,$destino,$idusuario,$observacion,$estadoaloja)
     {
       $ssql="update alojamiento set fechaingre='$fechaingre',fechasal='$fechasal',horaingre='$horaingre',procedencia='$procedencia',destino='$destino',idusuario=$idusuario,observacion='$observacion',estadoaloja='$estadoaloja' where idalojamiento=$idalojamiento";
       $this->BDConsulta($ssql);   
     }	 	 
	 function registrarDetServicio($idservicio,$idalojamiento,$precio,$fecha,$hora,$precios)
     {
       $ssql="Insert Into detalleservicio(idservicio,idalojamiento,precio,fecha,hora,precios) values($idservicio,$idalojamiento,$precio,'$fecha','$hora',$precios)";
       $this->BDConsulta($ssql);       
     }
	 function registrarCargaDetServicio($idservicio,$idalojamiento,$cantidad,$precio,$subtotal,$fecha,$hora,$precios,$subtotals,$um,$numvale)
     {
       $ssql="Insert Into detalleservicio(idservicio,idalojamiento,cantidad,precio,subtotal,fecha,hora,precios,subtotals,um,numvale) values($idservicio,$idalojamiento,$cantidad,$precio,$subtotal,'$fecha','$hora',$precios,$subtotals,'$um',$numvale)";
       $this->BDConsulta($ssql);
	   $id=$this->UltimoId();
	   return $id;       
     }
	 function registrarCiudad($idpais,$nombreciudad)
     {
       $ssql="Insert Into ciudad(idpais,nombreciudad) values($idpais,'$nombreciudad')";
       $this->BDConsulta($ssql);
	   $id=$this->UltimoId();
	   return $id;        
     } 
	 function UpdateEstadoHabit($idhabit,$estadohabit)
     {      
	   $ssql= " Update habitacion set estadohabit='$estadohabit' ";
       echo $ssql.=" Where idhabit=$idhabit";
       $this->BDConsulta($ssql);       
     }
	 function UpdateSalidadHuesped($idalojamiento,$fechasal,$horasal,$formapago,$numtarjeta,$total,$estadoaloja,$totals,$tipocomprobante,$numcomprobante,$cia,$ruc,$direccion)
     {      
	   $ssql= " Update alojamiento set fechasal='$fechasal',horasal='$horasal',formapago='$formapago',numtarjeta='$numtarjeta',total=$total,estadoaloja='$estadoaloja',totals=$totals,tipocomprobante='$tipocomprobante',numcomprobante='$numcomprobante',cia='$cia',ruc='$ruc',direccion='$direccion' ";
       echo $ssql.=" Where idalojamiento=$idalojamiento";
       $this->BDConsulta($ssql);       
     }
	 function UpdateSerHabitSal($iddetserv,$cantidad,$subtotal,$subtotals,$um)
     {      
	   $ssql= " Update detalleservicio set cantidad=$cantidad,subtotal=$subtotal,um=$um ";
       echo $ssql.=" Where iddetserv=$iddetserv";
       $this->BDConsulta($ssql);       
     }
	 function UpdateComprobante($tipo,$correlativo)
     {      
	   $ssql= " Update comprobantes set correlativo=$correlativo ";
       echo $ssql.=" Where tipo='$tipo'";
       $this->BDConsulta($ssql);       
     }
	 function UpdatePaises($idpais,$nacionalidad)
     {      
	   $ssql= " Update pais set nacionalidad='$nacionalidad' ";
       $ssql.=" Where idpais=$idpais";
       $this->BDConsulta($ssql);       
     }
	 function UpdateSerHabit($idpais,$cantidad,$subtotal,$precios,$subtotals,$um)
     {      
	   $ssql= " Update pais set nacionalidad='$nacionalidad' ";
       $ssql.=" Where idpais=$idpais";
       $this->BDConsulta($ssql);       
     }
	 function UpdateAlojaSal($idalojamiento,$fechasal,$horasal,$formapago,$numtarjeta,$total,$estadoaloja,$totals)
     {      
	   $ssql= " Update pais set fechasal='$fechasal',$horasal='$horasal',formapago='$formapago',numtarjeta='$numtarjeta',total=$total,estadoaloja='$estadoaloja',totals=$totals ";
       $ssql.=" where idalojamiento=$idalojamiento";
       $this->BDConsulta($ssql);       
     }
	 function DeleteAloja($idalojamiento)
     {      
	   $ssql= " delete from alojamiento ";
       $ssql.=" Where idalojamiento=$idalojamiento";
       $this->BDConsulta($ssql);       
     }
	 function DeleteHuesped($idhuesped)
     {      
	   $ssql= " delete from huesped ";
       $ssql.=" Where idhuesped=$idhuesped";
       $this->BDConsulta($ssql);       
     }
	 function registrarHuespedR($huesped,$agencia,$direccion,$telefono)
     {
      $ssql="Insert Into huesped(huesped,agencia,direccion,telefono) values('$huesped','$agencia','$direccion','$telefono')";
      $this->BDConsulta($ssql); 	   
	  $id=$this->UltimoId();
	  return $id;        
     }	                         
	 function registrarAlojamientoR($fechareserva,$horareserva,$fechaarribo,$horaarribo,$airline,$vuelo,$idusuario,$idhabit,$idhuesped,$observacion,$estadoaloja)
     {
       $ssql="Insert Into alojamiento(fechareserva,horareserva,fechaarribo,horaarribo,airline,vuelo,idusuario,idhabit,idhuesped,observacion,estadoaloja) values('$fechareserva','$horareserva','$fechaarribo','$horaarribo','$airline','$vuelo',$idusuario,$idhabit,$idhuesped,'$observacion','$estadoaloja')";
       $this->BDConsulta($ssql); 	   
	   $id=$this->UltimoId();
	   return $id; 
     }	 
	 
	 function listarUsuarios()
     {
       $ssql="select idusuario,apellidos,nombres ";
       $ssql.=" From usuario ";       
       return $this->BDConsulta($ssql);
     }
	 
     
     

   }

?>